#
# spec file for package python-subprocess-tee
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-subprocess-tee
Version:        0.4.1
Release:        6.2
Summary:        Captures the output of subprocesses in real-time
License:        MIT
URL:            https://github.com/pycontribs/subprocess-tee
Source:         https://files.pythonhosted.org/packages/source/s/subprocess-tee/subprocess-tee-%{version}.tar.gz
Patch1:         0001-test-test_unit.py-do-not-use-python3-rather-use-sys..patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module rich}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test
BuildRequires:  %{python_module enrich}
# /SECTION
BuildRequires:  fdupes
BuildArch:      noarch
%python_subpackages

%description
This package provides a drop-in alternative to `subprocess.run` that
captures the output while still printing it in real-time, just the way
`tee` does.

Printing output in real-time while still capturing is valuable for
any tool that executes long-running child processes. For those, you do want
to provide instant feedback (progress) related to what is happening.

%prep
%autosetup -p1 -n subprocess-tee-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# program "molecule" is no available in openSUSE. But this test is platform-independent, so not required
%pytest -k 'not test_molecule and not test_rich_console_ex'

%files %{python_files}
%{python_sitelib}/subprocess_tee/
%{python_sitelib}/subprocess_tee-%{version}*-info
%doc README.md
%license LICENSE

%changelog
* Thu May 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Mon Jul 17 2023 Steve Kowalik <steven.kowalik@suse.com>
- Remove BuildRequires on setuptools_scm_git_archive.
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add patch
  0001-test-test_unit.py-do-not-use-python3-rather-use-sys..patch
  to replace hardcoded python3 executable name
  (see https://github.com/pycontribs/subprocess-tee/pull/107)
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Sun Feb 12 2023 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire rich, otherwise the %%checks fail on SLES15 with
  the python3-module (rich is not being installed automatically)
* Tue Jan 31 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.4.1:
  * Bugfixes
  - Correct trove metadata related to supported platforms (#90) @ssbarnea
  - Move mypy config to pyproject.toml (#88) @ssbarnea
  - Stop using deprecated get_event_loop() (#86) @gotmax23
  - Configure packit (#81) @ssbarnea
  - Add "setuptools >= 61.0" to build system requires (#82) @gotmax23
  - Clear build dependencies (#80) @ssbarnea
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.4.0:
  * Minor Changes
  - Enable support for py311 (#72) @ssbarnea
  * Bugfixes
  - Remove support for py37 (#70) @ssbarnea
  - Remove support for py36 (#65) @ssbarnea
  - Mark test test_rich_console_ex as broken (#64) @ssbarnea
* Sun Sep 11 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Temporarily disable the failing test test_rich_console_ex to prevent a build fail
  reported upstream: https://github.com/pycontribs/subprocess-tee/issues/58
* Thu Mar 31 2022 Matej Cepl <mcepl@suse.com>
- Still missing BR: setuptools_scm_git_archive
* Thu Mar 31 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove dependency generator, as it is not adviced to do so
- add setuptools_scm as dependency to fix the version number
* Tue Mar 15 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Initial package for version 0.3.5.
